@@ -1,5 +1,6 @@
 #! /usr/bin/python
 # -*- coding: UTF-8 -*-
+from __future__ import print_function
 
 import sys, os, os.path, time
 from othman.core import othmanCore, searchIndexer
@@ -13,6 +14,6 @@ for n,(o,i) in enumerate(q.getAyatIter(1, 6236)):
         wc += 1
 d = os.path.dirname(sys.argv[0])
 ix.save()
-print "got %d words, %d terms (max term length=%d character, term vectors size=%d bytes)." % (wc, ix.terms_count, ix.maxWordLen, ix.term_vectors_size)
+print("got %d words, %d terms (max term length=%d character, term vectors size=%d bytes)." % (wc, ix.terms_count, ix.maxWordLen, ix.term_vectors_size))
 
 
